==> apachesolr_ajax-6.x-1.9.tar.gz: apachesolr_ajax/apachesolr_ajax.js <==
// $Id: apachesolr_ajax.js,v 1.11 2010/04/01 00:48:24 jpmckinney Exp $

Drupal.behaviors.apachesolr_ajax = function (context) {
  if (Drupal.settings.apachesolr_ajax) {
    var blocks  = Drupal.settings.apachesolr_ajax.blocks;
    var content = Drupal.settings.apachesolr_ajax.content;
    var regions = Drupal.settings.apachesolr_ajax.regions;
    var spinner = Drupal.settings.apachesolr_ajax.spinner;

    function apachesolr_ajax_url_to_state(url) {
	return url.replace(new RegExp('^.*' + Drupal.settings.basePath + '/search/apachesolr_\w+/?'), '');
    }

    function apachesolr_ajax_request_callback(state) {
      if (spinner) {
        if (content) {
          $(content).html($('<img/>').attr('src', spinner));
        }
      }
      $.post(Drupal.settings.basePath + 'search/apachesolr_ajax/' + state, { js: 1 }, apachesolr_ajax_response_callback, 'json');
    }

    function apachesolr_ajax_response_callback(data) {
      var list = [];

      // Schedule items for removal to reduce page jumpiness.
      if (blocks) {
        for (var block in blocks) {
          list.push($(blocks[block]));
        }
      }
      for (var region in data) {
        if (region == 'apachesolr_ajax') {
          if (content) {
            $(content).html(data[region]);
          }
        }
        else {
          for (var block in data[region]) {
            if (regions[region] && blocks[block]) {
              $(regions[region]).append(data[region][block]);
            }
          }
        }
      }
      for (var i = 0, l = list.length; i < l; i++) {
        list[i].remove();
      }

      // @see apachesolr.js
      if (Drupal.behaviors.apachesolr) {
        Drupal.behaviors.apachesolr(document);
      }
    }

    function apachesolr_ajax_navigate(url) {
      var state = apachesolr_ajax_url_to_state(url);
      try {
        YAHOO.util.History.navigate('q', state);
      }
      catch (e) {
        apachesolr_ajax_request_callback(state);
      }
      return false;
    }

    function apachesolr_ajax(selector) {
      $(selector + ' a[href*=' + Drupal.settings.basePath + 'search/apachesolr_]').livequery('click', function () {
        return apachesolr_ajax_navigate($(this).attr('href'));
      });
      $(selector + ' form[action*=' + Drupal.settings.basePath + 'search/apachesolr_]').livequery('submit', function () {
        return apachesolr_ajax_navigate($('#edit-keys').val()); // @todo Add support for retain-filters.
      });
    }

    var initialState = YAHOO.util.History.getBookmarkedState('q') || apachesolr_ajax_url_to_state(window.location.href);
    YAHOO.util.History.register('q', initialState, apachesolr_ajax_request_callback);

    YAHOO.util.History.onReady(function () {
      if (content) {
        apachesolr_ajax(content);
      }
      if (blocks) {
        for (var block in blocks) {
          apachesolr_ajax(blocks[block]);
        }
      }
      var currentState = YAHOO.util.History.getCurrentState('q');
      apachesolr_ajax_request_callback(currentState);
    });

    try {
      YAHOO.util.History.initialize('yui-history-field', 'yui-history-iframe');
    }
    catch (e) {
      apachesolr_ajax_request_callback(initialState);
    }
  }
}

==> apachesolr_ajax-6.x-1.10.tar.gz: apachesolr_ajax/apachesolr_ajax.js <==
// $Id: apachesolr_ajax.js,v 1.12 2010/06/20 05:44:41 jpmckinney Exp $

Drupal.behaviors.apachesolr_ajax = function (context) {
  if (Drupal.settings.apachesolr_ajax) {
    var blocks  = Drupal.settings.apachesolr_ajax.blocks;
    var content = Drupal.settings.apachesolr_ajax.content;
    var regions = Drupal.settings.apachesolr_ajax.regions;
    var spinner = Drupal.settings.apachesolr_ajax.spinner;

    function apachesolr_ajax_url_to_state(url) {
      return url.replace(new RegExp('^.*' + Drupal.settings.basePath + 'search/apachesolr_[a-z_]+/?'), '');
    }

    function apachesolr_ajax_request_callback(state) {
      if (spinner) {
        if (content) {
          $(content).html($('<img/>').attr('src', spinner));
        }
      }
      $.post(Drupal.settings.basePath + 'search/apachesolr_ajax/' + state, { js: 1 }, apachesolr_ajax_response_callback, 'json');
    }

    function apachesolr_ajax_response_callback(data) {
      var list = [];

      // Schedule items for removal to reduce page jumpiness.
      if (blocks) {
        for (var block in blocks) {
          list.push($(blocks[block]));
        }
      }
      for (var region in data) {
        if (region == 'apachesolr_ajax') {
          if (content) {
            $(content).html(data[region]);
          }
        }
        else {
          for (var block in data[region]) {
            if (regions[region] && blocks[block]) {
              $(regions[region]).append(data[region][block]);
            }
          }
        }
      }
      for (var i = 0, l = list.length; i < l; i++) {
        list[i].remove();
      }

      // @see apachesolr.js
      if (Drupal.behaviors.apachesolr) {
        Drupal.behaviors.apachesolr(document);
      }
    }

    function apachesolr_ajax_navigate(url) {
      var state = apachesolr_ajax_url_to_state(url);
      try {
        YAHOO.util.History.navigate('q', state);
      }
      catch (e) {
        apachesolr_ajax_request_callback(state);
      }
      return false;
    }

    function apachesolr_ajax(selector) {
      $(selector + ' a[href*=' + Drupal.settings.basePath + 'search/apachesolr_]').livequery('click', function () {
        return apachesolr_ajax_navigate($(this).attr('href'));
      });
      $(selector + ' form[action*=' + Drupal.settings.basePath + 'search/apachesolr_]').livequery('submit', function () {
        return apachesolr_ajax_navigate($('#edit-keys').val()); // @todo Add support for retain-filters.
      });
    }

    var initialState = YAHOO.util.History.getBookmarkedState('q') || apachesolr_ajax_url_to_state(window.location.href);
    YAHOO.util.History.register('q', initialState, apachesolr_ajax_request_callback);

    YAHOO.util.History.onReady(function () {
      if (content) {
        apachesolr_ajax(content);
      }
      if (blocks) {
        for (var block in blocks) {
          apachesolr_ajax(blocks[block]);
        }
      }
      var currentState = YAHOO.util.History.getCurrentState('q');
      apachesolr_ajax_request_callback(currentState);
    });

    try {
      YAHOO.util.History.initialize('yui-history-field', 'yui-history-iframe');
    }
    catch (e) {
      apachesolr_ajax_request_callback(initialState);
    }
  }
}
